@@ -1,5 +1,11 @@
-# -*- coding: utf-8 -*-
+"""
+``optimizationalgo.voyage``
+===========================
 
+Модуль, реализующий оптимизационные алгоритмы решения задачи коммивояжёра.
+Представлены следующие алгоритмы: имитация муравьиной колонии и симуляция отжига.
+
+"""
 import csv
 import math
 import time
